#!/bin/bash

set -e -u

# Script to create all the various distribution files into a given directory.
#
# Usage: mkccclientdist.sh <build config file> <destination directory>

scriptdir=`dirname $0`
scriptdir=`cd "${scriptdir}" && pwd`

if test $# -lt 2; then
    echo "Usage: mkalldist.sh <build config file> <destination directory>"
    exit 1
fi

buildconfig="${1}"
destdir="${2}"

tmpdir=`mktemp -d`
trap "rm -rf $tmpdir" EXIT

rm -rf "${destdir}"
mkdir -p "${destdir}"

"${scriptdir}/buildallhosts.sh" "${buildconfig}" "${tmpdir}"

for package in vscpl xplcommon xplra; do
    make -C "${tmpdir}/xpl/${package}" dist
    mv "${tmpdir}/xpl/${package}/"*.tar.gz "${destdir}"
done

"${scriptdir}/mkplugindist.sh" "${tmpdir}" "${destdir}"

"${scriptdir}/mkccclientdist.sh" "${tmpdir}/xpl" linux-x86_64.tar.gz "${destdir}"
"${scriptdir}/mkccclientdist.sh" "${tmpdir}/xpl-win64" win64.zip "${destdir}"

cd "${scriptdir}"
python3 setup.py sdist --formats zip -d "${destdir}"
